@@ -1000,7 +1000,7 @@ YAF_STARTUP_FUNCTION(loader) {
 
 	memcpy(&yaf_loader_obj_handlers, zend_get_std_object_handlers(), sizeof(zend_object_handlers));
 	yaf_loader_obj_handlers.clone_obj = NULL;
-	yaf_loader_obj_handlers.get_gc = NULL;
+	yaf_loader_obj_handlers.get_gc = yaf_fake_get_gc;
 	yaf_loader_obj_handlers.free_obj = yaf_loader_obj_free;
 	yaf_loader_obj_handlers.get_properties = yaf_loader_get_properties;
 
