@@ -149,7 +149,7 @@ static yaf_session_t *yaf_session_instance() /* {{{ */ {
 	sess->flags = 0;
 	yaf_session_start(sess);
 
-	if ((pzval = zend_hash_str_find(&EG(symbol_table), ZEND_STRL("_SESSION"))) == NULL ||
+	if ((pzval = zend_hash_find(&EG(symbol_table), YAF_KNOWN_STR(YAF_VAR_SESSION))) == NULL ||
 		Z_TYPE_P(pzval) != IS_REFERENCE || Z_TYPE_P(Z_REFVAL_P(pzval)) != IS_ARRAY) {
 		php_error_docref(NULL, E_WARNING, "Attempt to start session failed");
 		sess->session = NULL;
@@ -350,7 +350,7 @@ YAF_STARTUP_FUNCTION(session) {
 	yaf_session_obj_handlers.offset = XtOffsetOf(yaf_session_object, std);
 	yaf_session_obj_handlers.free_obj = yaf_session_object_free;
 	yaf_session_obj_handlers.clone_obj = NULL;
-	yaf_session_obj_handlers.get_gc = NULL;
+	yaf_session_obj_handlers.get_gc = yaf_fake_get_gc;
 	yaf_session_obj_handlers.get_properties = yaf_session_get_properties;
 
 #if defined(HAVE_SPL) && PHP_VERSION_ID < 70200
